﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
//-------------------------------------------------------------------------------
// (C) 2009-2017 CITIZEN SYSTEMS JAPAN CO., LTD. All Rights Reserved.
//-------------------------------------------------------------------------------
// Layout Utilities sample code [[ TestPrint ]] for VCS2010
//
// This program is the basic print sample cord which used a layout file.
// In addition, please understand that error processing is not performed.
//
// The command procedure that is necessary for print is as follows.
//
// [01] Creates the object.
// [02] Opens the layout file.                           Open
// [03] Initializes the object.                          BeginPrint
// [04] Gets an index of the frame.                      InitFrame
// [05] Gets an index of the part in the frame.          GetParts
// [06] Modifies the working area in the object.         SetPartsData
// [07] Copies the working area to the print area.       AddFrame
// [08] Starts the print.                                DoPrint
// [09] Cancels the work area.                           EndPrint
// [10] Clears all area in the object.                   Close
namespace TestPrint
{
	public partial class Form1 : Form
	{
		public Form1()
		{
			InitializeComponent();
		}

		private void Form1_Load(object sender, EventArgs e)
		{
			//-------------------------------------------------------------------------------
			// Gets all installed printers name in the OS.
			//-------------------------------------------------------------------------------
			foreach (string printerName in System.Drawing.Printing.PrinterSettings.InstalledPrinters)
			{
				comboBox1.Items.Add(printerName);

				//-------------------------------------------------------------------------------
				// Selects a CITIZEN printer
				//-------------------------------------------------------------------------------
				if ((0 > comboBox1.SelectedIndex) &&
					(0 <= printerName.ToUpper().IndexOf("CITIZEN")))
				{
					comboBox1.SelectedIndex = comboBox1.Items.Count - 1;
				}
			}
			//-------------------------------------------------------------------------------
			// Speedup of the first printing.
			//-------------------------------------------------------------------------------
			preparePrint(textBox1.Text);
		}

		private void button1_Click(object sender, EventArgs e)
		{
			//-------------------------------------------------------------------------------
			// Selects a custom layout file. (by common dialog)
			//-------------------------------------------------------------------------------
            OpenFileDialog ofd = new OpenFileDialog();
            ofd.InitialDirectory = @"..\..\";
            ofd.RestoreDirectory = true;
            ofd.Title = "Open a CLF file";
            ofd.Filter = "CLF files (*.clf)|*.clf";
            ofd.FileName = "";
            if (ofd.ShowDialog() == DialogResult.OK)
            {
                textBox1.Text = ofd.FileName;
				//-------------------------------------------------------------------------------
				// Speedup of the first printing.
				//-------------------------------------------------------------------------------
				preparePrint(textBox1.Text);
			}
		}

		private void button2_Click(object sender, EventArgs e)
		{
			//-----------------------------------------------------------------
			// Preparations
			//-----------------------------------------------------------------
			// [01] Creates the object.
			Citizen.LayoutUtilities.Printing.Controller clpc = new Citizen.LayoutUtilities.Printing.Controller();

			// [02] Opens the layout file.
			//      Argument : pathName
			int result = clpc.Open(textBox1.Text);

			// [03] Initializes the object.
			//      Initializes a result of InitFrame() and AddFrame().
			//      Argument : None
			clpc.BeginPrint();

			//-----------------------------------------------------------------
			// Modifies a value of "Text1" in "Frame1", and add it to the print area.
			//-----------------------------------------------------------------
			// [04] Gets an index of the frame.
			//      Copies the frame to the working area in the object.
			//      Argument : frameName
			int frameIndex = clpc.InitFrame("Frame1");

			// [05] Gets an index of the part in the frame.
			//      Argument : frameIndex, partName
			int partsIndex = clpc.GetParts(frameIndex, "Text1");

			// [06] Modifies the working area in the object.
			//      Argument : frameIndex, partIndex, setText
			result = clpc.SetPartsData(frameIndex, partsIndex, textBox2.Text);

			// [07] Copies the working area to the print area.
			//      Execute InitFrame() before this processing.
			//      Argument : frameIndex
			result = clpc.AddFrame(frameIndex);

			//-----------------------------------------------------------------
			// Prints the print area.
			//-----------------------------------------------------------------
			// [08] Starts the print.
			//      Execute AddFrame() before this processing.
			//      Argument : printerName (Blank : The default printer is used to print.)
			result = clpc.DoPrint(comboBox1.Text);

			//-----------------------------------------------------------------
			// Processing of end
			//-----------------------------------------------------------------
			// [09] Cancels the work area.
			//      Execute BeginPrint() or Close() after this processing.
			//      Argument : None
			clpc.EndPrint();

			// [10] Clears all area in the object.
			//      Execute Open() after this processing.
			//      Argument : None
			clpc.Close();
		}

		//-----------------------------------------------------------------
		// Improves the speed of the first printing.
		//-----------------------------------------------------------------
		private void preparePrint(string pathName)
		{
			Citizen.LayoutUtilities.Printing.Controller clpc = new Citizen.LayoutUtilities.Printing.Controller();
			int result = clpc.PreparePrint(pathName);
//			int result = clpc.HidePreview(pathName);
		}
	}
}
