﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
//-------------------------------------------------------------------------------
// (C) 2009-2017 CITIZEN SYSTEMS JAPAN CO., LTD. All Rights Reserved.
//-------------------------------------------------------------------------------
// Layout SDK (via Printer Driver), sample code [[ ReceiptPrint ]] for VCS2010
//
// This program assumed receipt print.
// It can easily change a print result by replacing a layout file.
// The following layout files are necessary for the execution of this program.
//
// CLF Layout File - PC font printing (Full graphic printing).
//   sample_48mm.CLF
//   sample_72mm.CLF
//   sample_48mm_landscape.CLF
//   sample_72mm_landscape.CLF
//
// In addition, please understand that error processing is not supported.
namespace ReceiptPrint
{
	public partial class Form1 : Form
	{

		string replaceLogo = @"..\..\newlogo.png";

		public Form1()
		{
			InitializeComponent();
		}

		private void Form1_Load(object sender, EventArgs e)
		{
			// Set the Layout file directory.
			String dir = System.IO.Path.Combine(Application.StartupPath, @"..\..\");
			System.IO.DirectoryInfo dirInfo = new System.IO.DirectoryInfo(dir);

			// Set the Layout file list.
			comboBox_LayoutFile_CLF.Items.AddRange(dirInfo.GetFiles("*.CLF"));
			if (comboBox_LayoutFile_CLF.Items.Count > 0)
				comboBox_LayoutFile_CLF.SelectedIndex = 0;

			// Set EventHandler
			button_Print.Click += new System.EventHandler(button_Print_Click);
			button_Preview.Click += new System.EventHandler(button_Preview_Click);

			// List the printers (ports).
			listPrinterDriver();

			//-------------------------------------------------------------------------------
			// Improve the first printing speed.
			//-------------------------------------------------------------------------------
			preparePrint(textBox_Header.Text);
		}


		private string getSelectedLayoutFile()
		{
			int index = comboBox_LayoutFile_CLF.SelectedIndex;
			System.IO.FileInfo fileInfo = (System.IO.FileInfo)comboBox_LayoutFile_CLF.Items[index];
			return fileInfo.FullName;
		}

		private string getSelectedPrinter()
		{
			if (listView_Printer.SelectedItems.Count == 0)
			{
				return "";
			}
			return listView_Printer.SelectedItems[0].Text;
		}



		private void button_Preview_Click(object sender, EventArgs e)
		{
			this.Enabled = false;
			print(true);
			this.Enabled = true;
		}

		private void button_Print_Click(object sender, EventArgs e)
		{
			this.Enabled = false;
			print(false);
			this.Enabled = true;
		}



		private void print(bool isPreview)
		{
			// Get the printer name.
			string printerName = getSelectedPrinter();

			// Get the layout file.
			string layoutFile = getSelectedLayoutFile();

			// Get the setting of Logo.
			bool isReplaceLogo = checkBox_ReplaceLogo.Checked;

			// Gets the print data.
			String header = textBox_Header.Text;
			String footer = textBox_Footer.Text; ;
			List<string> items = new List<string>();
			items.Add(textBox_Item01.Text);
			items.Add(textBox_Item02.Text);
			items.Add(textBox_Item03.Text);
			items.Add(textBox_Item04.Text);
			items.Add(textBox_Item05.Text);

			doPrint(printerName, layoutFile, isPreview, isReplaceLogo, header, footer, items.ToArray());
		}


		private void doPrint(string printerName, string layoutFile, bool isPreview, bool isReplaceLogo, string header, string footer, string[] items)
		{
			int result;
			int frameIndex;
			int partsIndex;
			//-----------------------------------------------------------------
			// Create Layout SDK object.
			// ( for via Printer Driver ) 
			//-----------------------------------------------------------------
			Citizen.LayoutUtilities.Printing.Controller clpc = new Citizen.LayoutUtilities.Printing.Controller();

			//-----------------------------------------------------------------
			// Open the layout file.
			//-----------------------------------------------------------------
			result = clpc.Open(layoutFile);
			if (result < 0)
			{
				string msg = "Please check the layout file. : " + layoutFile;
				Console.WriteLine(msg);
				MessageBoxIcon icon = MessageBoxIcon.Information;
				MessageBox.Show(msg + "  " + "(" + result.ToString() + ")", "Result", MessageBoxButtons.OK, icon);
			}
			else
			{
				//-----------------------------------------------------------------
				// Initialize the object.
				//-----------------------------------------------------------------
				clpc.BeginPrint();

				//-----------------------------------------------------------------
				// Add the header frame(Frame1) to the print area.
				//-----------------------------------------------------------------
				frameIndex = clpc.InitFrame("Frame1");
				partsIndex = clpc.GetParts(frameIndex, "Text1");
				result = clpc.SetPartsData(frameIndex, partsIndex, header);
				if (isReplaceLogo) {
					// Replace the bitmap.
					string bitmapPath = replaceLogo;
					partsIndex = clpc.GetParts(frameIndex, "Image1");
					result = clpc.SetPartsData(frameIndex, partsIndex, bitmapPath);
				}
				result = clpc.AddFrame(frameIndex);

				//-----------------------------------------------------------------
				// Replace the text of the item frame(Frame2) and add it to the print area.
				//-----------------------------------------------------------------
				int i = 0;
				foreach (string item in items)
				{
					frameIndex = clpc.InitFrame("Frame2");
					partsIndex = clpc.GetParts(frameIndex, "Text1");
					result = clpc.SetPartsData(frameIndex, partsIndex, item);
					// Make a dummy price.
					String price = makeDummyPrice(i++);
					partsIndex = clpc.GetParts(frameIndex, "Text2");
					result = clpc.SetPartsData(frameIndex, partsIndex, price);
					result = clpc.AddFrame(frameIndex);
				}

				//-----------------------------------------------------------------
				// Add the footer frame(Frame3) to the print area.
				//-----------------------------------------------------------------
				frameIndex = clpc.InitFrame("Frame3");
				partsIndex = clpc.GetParts(frameIndex, "Text1");
				result = clpc.SetPartsData(frameIndex, partsIndex, footer);
				partsIndex = clpc.GetParts(frameIndex, "Barcode1");
				result = clpc.SetPartsData(frameIndex, partsIndex, footer);
				result = clpc.AddFrame(frameIndex);

				//-----------------------------------------------------------------
				// Initialize the coupon frame(Frame4).
				// Please do not execute AddFrame() method, using InitFrame() method only.
				//-----------------------------------------------------------------
				frameIndex = clpc.InitFrame("Frame4");

				if (isPreview)
				{
					//-----------------------------------------------------------------
					// Preview the print area.
					//-----------------------------------------------------------------
					result = clpc.DoPreview(printerName);
				}
				else
				{
					//-----------------------------------------------------------------
					// Print the print area.
					//-----------------------------------------------------------------
					result = clpc.DoPrint(printerName);
				}

				//-----------------------------------------------------------------
				// End processing.
				//-----------------------------------------------------------------
				clpc.EndPrint();
				clpc.Close();
			}
		}
		
		private String makeDummyPrice(int digit)
		{
			// Make a dummy price.  (0.99, 9.99, 99.99,,,)
			double price = Math.Pow(10, digit) - 0.01;
			// Add the comma-separate.
			string s = price.ToString("N");
			return s;
		}


		/// <summary>
		/// Improve the first printing speed.
		/// </summary>
		/// <param name="pathName">Layout file name</param>
		private void preparePrint(string pathName)
		{
			Citizen.LayoutUtilities.Printing.Controller clpc = new Citizen.LayoutUtilities.Printing.Controller();
			int result = clpc.PreparePrint(pathName);
//			int result = clpc.HidePreview(pathName);
		}


		/// <summary>
		/// Gets all installed printers name in the OS.
		/// </summary>
		private void listPrinterDriver()
		{
			listView_Printer.Columns.Clear();
			listView_Printer.Columns.Add("Device", -2, HorizontalAlignment.Left);
			listView_Printer.Columns.Add("", 0, HorizontalAlignment.Left);
			listView_Printer.HeaderStyle = ColumnHeaderStyle.None;
			listView_Printer.Items.Clear();

			foreach (string printerName in System.Drawing.Printing.PrinterSettings.InstalledPrinters)
			{
				string[] printer = new string[2];
				printer[0] = printerName;
				printer[1] = "-";
				listView_Printer.Items.Add(new ListViewItem(printer));

				//-------------------------------------------------------------------------------
				// Selects a CITIZEN printer.
				//-------------------------------------------------------------------------------
				if ((0 >= listView_Printer.SelectedItems.Count) &&
					(0 <= printerName.ToUpper().IndexOf("CITIZEN")))
				{
					int idx = listView_Printer.Items.Count - 1;
					listView_Printer.Items[idx].EnsureVisible();
					listView_Printer.Items[idx].Focused = true;
					listView_Printer.Items[idx].Selected = true;
					listView_Printer.Select();
				}
			}
		}


	}
}
